@@ -91,77 +91,52 @@ printcmd_activated(GtkWidget *entry, gpointer user_data)
 }
 
 static void
-size_choice_activate(GtkWidget *choice, gpointer user_data)
+size_combo_box_changed(GtkWidget *combo_box, gpointer user_data)
 {
         GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-        gint i, n;
 
-        n = gtk_gs_defaults_get_paper_count();
-        for(i = 0; i < n; i++)
-                if(choice == dlg->size_choice[i]) {
-                        gtk_gs_defaults_set_size(i);
-                        break;
-                }
+        gtk_gs_defaults_set_size
+                (gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box)));
 }
 
 static void
-zoom_choice_activate(GtkWidget *choice, gpointer user_data)
+zoom_combo_box_changed(GtkWidget *combo_box, gpointer user_data)
 {
         GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-        gint i;
 
-        for(i = 0; i <= ggv_max_zoom_levels; i++){
-                if(choice == dlg->zoom_choice[i]) {
-                        gtk_gs_defaults_set_zoom_factor(ggv_zoom_levels[i]);
-                        break;
-                }
-        }
+        gtk_gs_defaults_set_zoom_factor
+                (ggv_zoom_levels
+                 [gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box))]);
 }
 
 
 static void
-orientation_choice_activate(GtkWidget *choice, gpointer user_data)
+orientation_combo_box_changed(GtkWidget *combo_box, gpointer user_data)
 {
         GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-        gint i;
 
-        for(i = 0; i <= ggv_max_orientation_labels; i++){
-                if(choice == dlg->orientation_choice[i]) {
-                        gtk_gs_defaults_set_orientation(i);
-                        break;
-                }
-        }
+        gtk_gs_defaults_set_orientation
+                (gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box)));
 }
 
 
 static void
-unit_choice_activate(GtkWidget *choice, gpointer user_data)
+unit_combo_box_changed(GtkWidget *combo_box, gpointer user_data)
 {
         GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-        gint i;
 
-        for(i = 0; i <= ggv_max_unit_labels; i++){
-                if(choice == dlg->unit_choice[i]) {
-                        ggv_unit_index = i;
-                        break;
-                }
-        }
+        ggv_unit_index = gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box));
         gconf_client_set_int(gconf_client, "/apps/ggv/coordinates/units",
                              ggv_unit_index, NULL);
 }
 
 static void
-autofit_choice_activate(GtkWidget *choice, gpointer user_data)
+autofit_combo_box_changed(GtkWidget *combo_box, gpointer user_data)
 {
         GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-        gint i;
 
-        for(i = 0; i <= ggv_max_auto_fit_modes; i++){
-                if(choice == dlg->auto_fit_choice[i]) {
-                        gtk_gs_defaults_set_zoom_mode(i);
-                        break;
-                }
-        }
+        gtk_gs_defaults_set_zoom_mode
+                (gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box)));
 }
 
 static void
@@ -242,25 +217,6 @@ show_toolbar_clicked(GtkWidget *w, gpointer user_data)
                               ggv_toolbar, NULL);
 }
 
-
-static void
-toolbar_style_toggled(GtkWidget *w, gpointer user_data)
-{
-        GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-        gint i;
-
-        for(i = 0; i < GGV_TOOLBAR_STYLE_LAST; i++) {
-                if(GTK_TOGGLE_BUTTON(dlg->tbstyle[i])->active) {
-                        ggv_toolbar_style = (GgvToolbarStyle)i;
-                        break;
-                }
-        }
-        if(i == GGV_TOOLBAR_STYLE_LAST)
-                ggv_toolbar_style = GGV_TOOLBAR_STYLE_DEFAULT;
-        gconf_client_set_int(gconf_client, "/apps/ggv/layout/toolbarstyle",
-                             ggv_toolbar_style, NULL);
-}
-
 static void
 show_menubar_clicked(GtkWidget *w, gpointer user_data)
 {
@@ -376,21 +332,21 @@ ggv_prefs_dialog_setup(GgvPrefsDialog *dlg)
                                 opt = i;
                                 mindist = dist;
                         }
-                        gtk_option_menu_set_history(GTK_OPTION_MENU(dlg->zoom), opt);
+                        gtk_combo_box_set_active(GTK_COMBO_BOX(dlg->zoom), opt);
                 }
         }
 
         /* set unit */
-        gtk_option_menu_set_history(GTK_OPTION_MENU(dlg->units),
-                                    ggv_unit_index);
+        gtk_combo_box_set_active(GTK_COMBO_BOX(dlg->units),
+                                 ggv_unit_index);
 
         /* set auto-fit mode */
-        gtk_option_menu_set_history(GTK_OPTION_MENU(dlg->auto_fit),
-                                    gtk_gs_defaults_get_zoom_mode());
+        gtk_combo_box_set_active(GTK_COMBO_BOX(dlg->auto_fit),
+                                 gtk_gs_defaults_get_zoom_mode());
 
         /* set default size */
         i = gtk_gs_defaults_get_size();
-        gtk_option_menu_set_history(GTK_OPTION_MENU(dlg->size), i);
+        gtk_combo_box_set_active(GTK_COMBO_BOX(dlg->size), i);
         
         /* set override size */
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->override_size), 
@@ -398,7 +354,7 @@ ggv_prefs_dialog_setup(GgvPrefsDialog *dlg)
 
         /* set fallback orientation */
         i = gtk_gs_defaults_get_orientation();
-        gtk_option_menu_set_history(GTK_OPTION_MENU(dlg->orientation), i);
+        gtk_combo_box_set_active(GTK_COMBO_BOX(dlg->orientation), i);
 
         /* set override orientation */
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->override_orientation), 
@@ -426,8 +382,6 @@ ggv_prefs_dialog_setup(GgvPrefsDialog *dlg)
                                      ggv_menubar);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->toolbar),
                                      ggv_toolbar);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->tbstyle[ggv_toolbar_style]),
-                                     TRUE);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->sbar),
                                      ggv_statusbar);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->savegeo),
@@ -551,11 +505,6 @@ ggv_prefs_dialog_new()
 
         gtk_window_set_title(GTK_WINDOW(dlg), _("GGV Preferences"));
 
-        dlg->zoom_choice = g_new0(GtkWidget *, ggv_max_zoom_levels + 1);
-        dlg->orientation_choice = g_new0(GtkWidget *, ggv_max_orientation_labels + 1);
-        dlg->unit_choice = g_new0(GtkWidget *, ggv_max_unit_labels + 1);
-        dlg->auto_fit_choice = g_new0(GtkWidget *, ggv_max_auto_fit_modes + 1);
-
         /* Document page */
         table = gtk_table_new(10, 2, FALSE);
 
@@ -571,21 +520,16 @@ ggv_prefs_dialog_new()
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 
         gtk_widget_show(label);
-        dlg->zoom = gtk_option_menu_new();
+        dlg->zoom = gtk_combo_box_new_text();
         gtk_widget_show(dlg->zoom);
-        menu = gtk_menu_new();
 
         /* We only go as far a as MENU_ZOOM_SIZE-1 because the last option
            is "other" */
-        for(i = 0; i <= ggv_max_zoom_levels; i++) {
-                dlg->zoom_choice[i] = gtk_menu_item_new_with_label(ggv_zoom_level_names[i]);
-                gtk_widget_show(dlg->zoom_choice[i]);
-                gtk_menu_shell_append(GTK_MENU_SHELL(menu), dlg->zoom_choice[i]);
-                g_signal_connect(G_OBJECT(dlg->zoom_choice[i]),
-                                 "activate",
-                                 G_CALLBACK(zoom_choice_activate), dlg);
-        }
-        gtk_option_menu_set_menu(GTK_OPTION_MENU(dlg->zoom), menu);
+        for(i = 0; i <= ggv_max_zoom_levels; i++)
+                gtk_combo_box_append_text(GTK_COMBO_BOX(dlg->zoom),
+                                          ggv_zoom_level_names[i]);
+        g_signal_connect(G_OBJECT(dlg->zoom), "changed",
+                         G_CALLBACK(zoom_combo_box_changed), dlg);
 
         gtk_table_attach(GTK_TABLE(table), dlg->zoom,
                          1, 2, 0, 1,
@@ -606,18 +550,13 @@ ggv_prefs_dialog_new()
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 
         gtk_widget_show(label);
-        dlg->auto_fit = gtk_option_menu_new();
+        dlg->auto_fit = gtk_combo_box_new_text();
         gtk_widget_show(dlg->auto_fit);
-        menu = gtk_menu_new();
-        for(i = 0; i <= ggv_max_auto_fit_modes; i++) {
-                dlg->auto_fit_choice[i] = gtk_menu_item_new_with_label(_(ggv_auto_fit_modes[i]));
-                gtk_widget_show(dlg->auto_fit_choice[i]);
-                gtk_menu_shell_append(GTK_MENU_SHELL(menu), dlg->auto_fit_choice[i]);
-                g_signal_connect(G_OBJECT(dlg->auto_fit_choice[i]),
-                                 "activate",
-                                 G_CALLBACK(autofit_choice_activate), dlg);
-        }
-        gtk_option_menu_set_menu(GTK_OPTION_MENU(dlg->auto_fit), menu);
+        for(i = 0; i <= ggv_max_auto_fit_modes; i++)
+                gtk_combo_box_append_text(GTK_COMBO_BOX(dlg->auto_fit),
+                                          _(ggv_auto_fit_modes[i]));
+        g_signal_connect(G_OBJECT(dlg->auto_fit), "changed",
+                                 G_CALLBACK(autofit_combo_box_changed), dlg);
 
         gtk_table_attach(GTK_TABLE(table), dlg->auto_fit,
                          1, 2, 1, 2,
@@ -638,18 +577,13 @@ ggv_prefs_dialog_new()
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 
         gtk_widget_show(label);
-        dlg->units = gtk_option_menu_new();
+        dlg->units = gtk_combo_box_new_text();
         gtk_widget_show(dlg->units);
-        menu = gtk_menu_new();
-        for(i = 0; i <= ggv_max_unit_labels; i++) {
-                dlg->unit_choice[i] = gtk_menu_item_new_with_label(_(ggv_unit_labels[i]));
-                gtk_widget_show(dlg->unit_choice[i]);
-                gtk_menu_shell_append(GTK_MENU_SHELL(menu), dlg->unit_choice[i]);
-                g_signal_connect(G_OBJECT(dlg->unit_choice[i]),
-                                 "activate",
-                                 G_CALLBACK(unit_choice_activate), dlg);
-        }
-        gtk_option_menu_set_menu(GTK_OPTION_MENU(dlg->units), menu);
+        for(i = 0; i <= ggv_max_unit_labels; i++)
+                gtk_combo_box_append_text(GTK_COMBO_BOX(dlg->units),
+                                          _(ggv_unit_labels[i]));
+        g_signal_connect(G_OBJECT(dlg->units), "changed",
+                         G_CALLBACK(unit_combo_box_changed), dlg);
 
         gtk_table_attach(GTK_TABLE(table), dlg->units,
                          1, 2, 2, 3,
@@ -668,19 +602,13 @@ ggv_prefs_dialog_new()
                          GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         gtk_widget_show(label);
-        dlg->size = gtk_option_menu_new();
+        dlg->size = gtk_combo_box_new_text();
         gtk_widget_show(dlg->size);
-        menu = gtk_menu_new();
-        dlg->size_choice = g_new0(GtkWidget *, gtk_gs_defaults_get_paper_count());
-        for(i = 0; papersizes[i].name != NULL; i++) {
-                dlg->size_choice[i] = gtk_menu_item_new_with_label(_(papersizes[i].name));
-                gtk_widget_show(dlg->size_choice[i]);
-                gtk_menu_shell_append(GTK_MENU_SHELL(menu), dlg->size_choice[i]);
-                g_signal_connect(G_OBJECT(dlg->size_choice[i]),
-                                 "activate",
-                                 G_CALLBACK(size_choice_activate), dlg);
-        }
-        gtk_option_menu_set_menu(GTK_OPTION_MENU(dlg->size), menu);
+        for(i = 0; papersizes[i].name != NULL; i++)
+                gtk_combo_box_append_text(GTK_COMBO_BOX(dlg->size),
+                                          _(papersizes[i].name));
+        g_signal_connect(G_OBJECT(dlg->size), "changed",
+                         G_CALLBACK(size_combo_box_changed), dlg);
 
         gtk_table_attach(GTK_TABLE(table), dlg->size,
                          1, 2, 3, 4,
@@ -710,18 +638,13 @@ ggv_prefs_dialog_new()
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         gtk_widget_show(label);
 
-        dlg->orientation = gtk_option_menu_new();
+        dlg->orientation = gtk_combo_box_new_text();
         gtk_widget_show(dlg->orientation);
-        menu = gtk_menu_new();
-        for(i = 0; i <= ggv_max_orientation_labels; i++) {
-                dlg->orientation_choice[i] = gtk_menu_item_new_with_label(_(ggv_orientation_labels[i]));
-                gtk_widget_show(dlg->orientation_choice[i]);
-                gtk_menu_shell_append(GTK_MENU_SHELL(menu), dlg->orientation_choice[i]);
-                g_signal_connect(G_OBJECT(dlg->orientation_choice[i]),
-                                 "activate",
-                                 G_CALLBACK(orientation_choice_activate), dlg);
-        }
-        gtk_option_menu_set_menu(GTK_OPTION_MENU(dlg->orientation), menu);
+        for(i = 0; i <= ggv_max_orientation_labels; i++)
+                gtk_combo_box_append_text(GTK_COMBO_BOX(dlg->orientation),
+                                          _(ggv_orientation_labels[i]));
+        g_signal_connect(G_OBJECT(dlg->orientation), "changed",
+                         G_CALLBACK(orientation_combo_box_changed), dlg);
 
         gtk_table_attach(GTK_TABLE(table), dlg->orientation,
                          1, 2, 5, 6,
@@ -780,7 +703,7 @@ ggv_prefs_dialog_new()
         gtk_notebook_append_page(GTK_NOTEBOOK(dlg->notebook), table, label);
 
         /* Layout page */
-        table = gtk_table_new(7, 1, FALSE);
+        table = gtk_table_new(6, 1, FALSE);
 
         /* show side panel */
         dlg->sidebar = gtk_check_button_new_with_mnemonic(_("_Show side panel"));
@@ -824,32 +747,10 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(show_toolbar_clicked), dlg);
         gtk_widget_show(dlg->toolbar);
 
-        /* toolbar style */
-        frame = gtk_frame_new(_("Toolbar style"));
-        gtk_widget_show(frame);
-        vbox = gtk_vbox_new(TRUE, 0);
-        gtk_container_add(GTK_CONTAINER(frame), vbox);
-        gtk_widget_show(vbox);
-        gtk_table_attach(GTK_TABLE(table), frame,
-                         0, 1, 4, 5,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_SHRINK | GTK_FILL,
-                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-        for(i = 0; i < GGV_TOOLBAR_STYLE_LAST; i++) {
-                dlg->tbstyle[i] = gtk_radio_button_new_with_mnemonic(tbstyle_group,
-                                                                  _(tbstyle_labels[i]));
-                tbstyle_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(dlg->tbstyle[i]));
-                g_signal_connect(G_OBJECT(dlg->tbstyle[i]), "toggled",
-                                 G_CALLBACK(toolbar_style_toggled), dlg);
-                gtk_widget_show(dlg->tbstyle[i]);
-                gtk_box_pack_start(GTK_BOX(vbox), dlg->tbstyle[i], TRUE, TRUE,
-                                   GNOME_PAD_SMALL);
-        }
-                                   
         /* show statusbar */
         dlg->sbar = gtk_check_button_new_with_mnemonic(_("Show statusba_r"));
         gtk_table_attach(GTK_TABLE(table), dlg->sbar,
-                         0, 1, 5, 6,
+                         0, 1, 4, 5,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
@@ -860,7 +761,7 @@ ggv_prefs_dialog_new()
         /* save geometry */
         dlg->savegeo = gtk_check_button_new_with_mnemonic(_("Save _geometry"));
         gtk_table_attach(GTK_TABLE(table), dlg->savegeo,
-                         0, 1, 6, 7,
+                         0, 1, 5, 6,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
